@@ -22,6 +22,23 @@ class Graph:
     edges: Set[ModuleEdge] = dataclasses.field(default_factory=set)
     clusters: Dict[ModuleNode, Cluster] = dataclasses.field(default_factory=dict)
 
+    def __post_init__(self):
+        self.reset()
+
+    def reset(self) -> None:
+        self.nodes.clear()
+        self.edges.clear()
+        self.clusters.clear()
+
+        # トップレベルの依存関係をGraphに追加する
+        for edge in self.master_graph.edges:
+            tail = edge.tail.path_in_depth(1).name
+            head = edge.head.path_in_depth(1).name
+            if tail == head:
+                self.add_node(ModuleNode.from_str(tail))
+            else:
+                self.add_edge(ModuleEdge.from_str(tail=tail, head=head))
+
     def to_dict(self) -> dict:
         nodes = sorted([n.name for n in self.nodes])
         edges = sorted([(e.tail.name, e.head.name) for e in self.edges])
@@ -61,6 +78,16 @@ class Graph:
 
         self.clusters[cluster.node] = cluster
 
+    def has_cluster(self, node: ModuleNode) -> bool:
+        if node in self.clusters:
+            return True
+
+        for cluster in self.clusters.values():
+            if cluster.has_cluster(node):
+                return True
+
+        return False
+
     def remove_node(self, node: ModuleNode):
         if node in self.nodes:
             self.nodes.remove(node)
@@ -111,6 +138,15 @@ class Graph:
             self.edges.remove(edge)
             self.edges.add(edge.with_style(style=edge_style))
 
+    def reset_style(self) -> None:
+        nodes = [node.reset_style() for node in self.nodes]
+        self.nodes.clear()
+        self.nodes.update(nodes)
+
+        edges = [edge.reset_style() for edge in self.edges]
+        self.edges.clear()
+        self.edges.update(edges)
+
     def auto_highlight(self):
         source_nodes: Dict[ModuleNode, List[ModuleEdge]] = dict(
             [(node, []) for node in self.nodes]
@@ -157,6 +193,10 @@ class Graph:
         return [e.tail for e in self.edges if e.head == node]
 
     def dig(self, node: ModuleNode):
+        if self.has_cluster(node):
+            # 既にクラスタ化されているので、処理をスキップする
+            return
+
         node_owner = self.find_node_owner(node)
         if not node_owner:
             raise ValueError(f"指定されたモジュール {node.name} が存在しません。")
